Lo! Death has reared himself a throne  
In a strange city lying alone  
Far down within the dim West,  
Where the good and the bad and the worst and the best  
Have gone to their eternal rest.  
There shrines and palaces and towers  
(Time-eaten towers and tremble not!)  
Resemble nothing that is ours.  
Around, by lifting winds forgot,
Resignedly beneath the sky  
The melancholy waters lie.  

No rays from the holy Heaven come down  
On the long night-time of that town;  
But light from out the lurid sea  
Streams up the turrets silently—  
Gleams up the pinnacles far and free—  
Up domes—up spires—up kingly halls—  
Up fanes—up Babylon-like walls—  
Up shadowy long-forgotten bowers  
Of sculptured ivy and stone flowers—  
Up many and many a marvellous shrine  
Whose wreathed friezes intertwine  
The viol, the violet, and the vine.  
Resignedly beneath the sky  
The melancholy waters lie.  
So blend the turrets and shadows there  
That all seem pendulous in air,  
While from a proud tower in the town  
Death looks gigantically down.  

There open fanes and gaping graves  
Yawn level with the luminous waves;  
But not the riches there that lie  
In each idol’s diamond eye—  
Not the gaily-jewelled dead  
Tempt the waters from their bed;  
For no ripples curl, alas!  
Along that wilderness of glass—  
No swellings tell that winds may be  
Upon some far-off happier sea—  
No heavings hint that winds have been  
On seas less hideously serene.  

But lo, a stir is in the air!  
The wave—there is a movement there!  
As if the towers had thrust aside,  
In slightly sinking, the dull tide—  
As if their tops had feebly given  
A void within the filmy Heaven.  
The waves have now a redder glow—  
The hours are breathing faint and low—  
And when, amid no earthly moans,  
Down, down that town shall settle hence,  
Hell, rising from a thousand thrones,  
Shall do it reverence.